/*  MaViLla: Marcador y Visualizador de Llamadas
 *
 *  Copyright (C) 2011  Area de Servicios Telematicos
 *			CSIRC
 *			Universidad de Granada
 *			telematica@ugr.es
 *  
 *  Version: 1.0
 *  Last Modified: 13 Abril 2010
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef LLAMADA_ENTRANTE_H
#define LLAMADA_ENTRANTE_H

#include <QDialog>
#include <QtNetwork/QtNetwork>
#include <QUrl>

#include "main.h"
#include "llamada_saliente.h"

QT_BEGIN_NAMESPACE

class QAbstractItemModel;

QT_END_NAMESPACE

namespace Ui {
    class Llamada_entrante;
}

class Llamada_entrante : public QDialog
{
    Q_OBJECT

private slots:

    /**
    @brief Slot que se ejecutara cuando clickeamos dos veces sobre un contacto

    Realiza una llamada al numero asociado al contacto que tengamos seleccionado.
    */
    void llamar();

public:

    /**
    @brief Constructor por defecto
    @param dirpath Contiene el path donde se encuentra el fichero de audio a reproducir
    @param parent widget Padre
    */
    explicit Llamada_entrante(QString dirpath = "./",QWidget *parent = 0);

    /**
    @brief Aade una nueva entrada a la tabla de llamadas
    @param nombre Contiene el nombre de la llamada entrante
    @param telefono Contiene el telefono de la llamada entrante
    @param imp Especifica si la llamada entrante es importante o no
    */
    void addEntrada(const QString &nombre,const QString &telefono, const bool &imp = false);

    /**
    @brief Destructor por defecto

    Libera la memoria reservada
    */
    ~Llamada_entrante();


private:
    Ui::Llamada_entrante *ui;
    QAbstractItemModel *modelo; // Modelo tabla central
    QUrl url; // Url para llamar
    QNetworkAccessManager qnam;
    Llamada_saliente * llam_sal; // Muestra la informacion al llamar
    QString path; // Donde esta la aplicacion

    /**
    @brief Devuelve el numero de la fila seleccionada en la tabla
    @return numero de fila seleccionada
    */
    int filaSeleccionada();
};

#endif // LLAMADA_ENTRANTE_H
